==> haskell-quickcheck-instances-0.3.30-54.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-GCugrzOy6REIzAShqpxDS
key:                  quickcheck-instances-0.3.30-GCugrzOy6REIzAShqpxDS
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  b57a9246f1f0069a2f49da934ecf904a
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-GCugrzOy6REIzAShqpxDS
depends:
    OneTuple-0.3.1-FCz2xnE00b94Ogh6y4sDd8
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED array-0.5.4.0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT containers-0.6.5.1
    data-array-byte-0.1.0.1-LhjadnRSQr4LDU6AcGeTDD
    data-fix-0.3.2-6VhLcs0YNJcBA65UokDP9z
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    integer-logarithms-1.0.3.1-6P0sCe8RoauAWF13sn9GHc
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc
    splitmix-0.1.0.5-4IFL1NtOdKh2TjOwEHJjMs
    strict-0.4.0.1-Ih3UIkZoif1LJOflpapyb8
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    text-short-0.1.5-Fk3sjbBdxESAT5k4wI1pbn
    these-1.1.1.1-CyiAda0CLBVAJ3SurHOVRa time-1.11.1.1
    time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    uuid-types-1.0.5.1-DzR0IgzRElQ1K705w84ENs
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.30-72-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-DCB0YUBPiLX2df5hCjMcnG
key:                  quickcheck-instances-0.3.30-DCB0YUBPiLX2df5hCjMcnG
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  9b5f4f095fce151a60b077d8d79f0782
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-DCB0YUBPiLX2df5hCjMcnG
depends:
    OneTuple-0.4.1-HV7N8vLWC8GJ6CEaZb8jlF
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X array-0.5.4.0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh containers-0.6.5.1
    data-array-byte-0.1.0.1-31kF3UWpQGYCpwbtQXGDZf
    data-fix-0.3.2-KVL4Ssf3XWfDD782889QEI
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    integer-logarithms-1.0.3.1-6P0sCe8RoauAWF13sn9GHc
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    splitmix-0.1.0.5-HVESxjxwSfmC4HE369voNE
    strict-0.4.0.1-Kjf7tvWS05h7ff3Eq8uXou
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0
    text-short-0.1.6-G6JGIda4tWsA5PFQaI0JR5
    these-1.1.1.1-FlLT2KU4YN4BBIgA41WfSa time-1.11.1.1
    time-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    uuid-types-1.0.5.1-EtLF0k28bNc38E21nOo17r
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
